@@ -19,6 +19,7 @@ from mypy_boto3_builder.constants import (
 from mypy_boto3_builder.jinja_manager import JinjaManager
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
+from mypy_boto3_builder.utils.boto3_changelog import Boto3Changelog
 from mypy_boto3_builder.utils.strings import (
     get_anchor_link,
     get_botocore_class_name,
@@ -34,6 +35,44 @@ from mypy_boto3_builder.writers.processors import (
 )
 
 
+def get_selected_service_names(
+    selected: Iterable[str],
+    available: Iterable[ServiceName],
+) -> list[ServiceName]:
+    """
+    Get a list of selected service names.
+
+    Supports `updated` to select only services updated in currect `boto3` release.
+    Supports `all` to select all available service names.
+
+    Arguments:
+        selected -- Selected service names as strings.
+        available -- All ServiceNames available in current boto3 release.
+
+    Returns:
+        A list of selected ServiceNames.
+    """
+    logger = get_logger()
+    available_map = {i.name: i for i in available}
+    result: list[ServiceName] = []
+    selected_service_names = list(selected)
+    if ServiceName.ALL in selected_service_names:
+        return list(available)
+    if ServiceName.UPDATED in selected_service_names:
+        selected_service_names.remove(ServiceName.UPDATED)
+        for updated_service_name in Boto3Changelog().get_updated_service_names(boto3_version):
+            if updated_service_name in available_map:
+                selected_service_names.append(updated_service_name)
+
+    for service_name_str in selected_service_names:
+        if service_name_str not in available_map:
+            logger.info(f"Service {service_name_str} is not provided by boto3, skipping")
+            continue
+        result.append(available_map[service_name_str])
+
+    return result
+
+
 def get_available_service_names(session: Session) -> list[ServiceName]:
     """
     Get a list of boto3 supported service names.
@@ -45,7 +84,7 @@ def get_available_service_names(session: Session) -> list[ServiceName]:
         A list of supported services.
     """
     available_services = session.get_available_services()
-    botocore_session = session._session  # type: ignore
+    botocore_session = session._session
     result: list[ServiceName] = []
     for name in available_services:
         service_data = botocore_session.get_service_data(name)
@@ -63,14 +102,14 @@ def main() -> None:
     args = parse_args(sys.argv[1:])
     logger = get_logger(level=args.log_level)
     session = Session(region_name=DUMMY_REGION)
-    session._session.set_credentials("access_key", "secret_key", "token")  # type: ignore
+
+    botocore_session = session._session
+    botocore_session.set_credentials("access_key", "secret_key", "token")
 
     args.output_path.mkdir(exist_ok=True)
     available_service_names = get_available_service_names(session)
-    available_service_names_set = {i.name for i in available_service_names}
-    service_names: list[ServiceName] = []
 
-    logger.info(f"{len(available_service_names_set)} supported boto3 services discovered")
+    logger.info(f"{len(available_service_names)} supported boto3 services discovered")
     if args.list_services:
         for service_name in available_service_names:
             print(
@@ -78,15 +117,7 @@ def main() -> None:
             )
         return
 
-    selected_service_names = args.service_names or [i.name for i in available_service_names]
-
-    for service_name_str in selected_service_names:
-        if service_name_str not in available_service_names_set:
-            logger.info(f"Service {service_name_str} is not provided by boto3, skipping")
-            continue
-
-        service_name = ServiceNameCatalog.find(service_name_str)
-        service_names.append(service_name)
+    service_names = get_selected_service_names(args.service_names, available_service_names)
 
     build_version = args.build_version or boto3_version
     min_build_version = get_min_build_version(build_version)
