@@ -1,7 +1,7 @@
 """
 Structure for boto3-stubs module.
 """
-from typing import Iterable, List
+from collections.abc import Iterable
 
 from mypy_boto3_builder.constants import MODULE_NAME, PYPI_NAME
 from mypy_boto3_builder.service_name import ServiceName
@@ -32,11 +32,11 @@ class MasterPackage(Package):
         self.service_packages = list(service_packages)
 
     @property
-    def essential_service_names(self) -> List[ServiceName]:
+    def essential_service_names(self) -> list[ServiceName]:
         """
         List of services maked as essential.
         """
-        result: List[ServiceName] = []
+        result: list[ServiceName] = []
         for service_name in self.service_names:
             if service_name.is_essential():
                 result.append(service_name)
